@@ -33,6 +33,10 @@ selectnet = function(netgwas.obj, opt.index = NULL, criteria = NULL, ebic.gamma
 	par.cor[par.cor > 1] <- 1
 	sel$par.cor <- Matrix(par.cor)
 	
+	A <- graph.adjacency(sel$opt.adj, mode = "undirected")
+	sel$V.names <- names (which (degree(A) != 0 )) 
+	
+	  
 	rm(par.cor, theta, netgwas.obj)
 	class(sel) = "select"
 	return(sel)
@@ -50,7 +54,7 @@ readkey <- function()
 # Email: <pariya.Behrouzi@gmail.com>                  #
 #-----------------------------------------------------#
 plot.select = function(x, vis= NULL, xlab= NULL, ylab= NULL, n.mem = NULL, vertex.label = FALSE, ..., layout = NULL, label.vertex = "all", vertex.size = NULL, vertex.color = NULL , edge.color = "gray29", sel.nod.label = NULL, label.size = NULL, w.btw= 800, w.within = 10,
-                  sign.edg= TRUE, edge.width= NULL, edge.label= NULL,  max.degree= NULL, layout.tree= NULL, root.node= NULL, degree.node= NULL, curve= FALSE, pos.legend= "bottomleft", cex.legend= 0.8, iterl = NULL, temp = NULL, tk.width = NULL, tk.height= NULL)
+                  sign.edg= TRUE, edge.width= NULL, edge.label= NULL,  max.degree= NULL, layout.tree= NULL, root.node= NULL, degree.node= NULL, curve= FALSE, delet.v =TRUE, pos.legend= "bottomleft", cex.legend= 0.8, iterl = NULL, temp = NULL, tk.width = NULL, tk.height= NULL)
   #plot.select = function(x, vis= NULL, xlab= NULL, ylab= NULL, n.mem = NULL, vertex.label = FALSE, ..., layout = NULL, label.vertex = "all", vertex.size = NULL, vertex.color = "red" , edge.color = "gray29", sel.nod.label = NULL, label.size = NULL, w.btw= 800, w.within = 10)
 {
 	if(class(x) != "select") stop("The input of this plot function should be from \"select\" class (More info in: selectnet( ) ). \n")
@@ -60,6 +64,18 @@ plot.select = function(x, vis= NULL, xlab= NULL, ylab= NULL, n.mem = NULL, verte
 	plot.new()
 	par(mfrow= c(1,1))
 	
+	if(delet.v == TRUE)
+	  {
+  	  A <- graph.adjacency(x$opt.adj, mode = "undirected")
+  	  A <- delete.vertices(A, degree(A) == 0)
+  	  x$opt.adj <- Matrix(as_adj(A))
+   	  x$par.cor   <- Matrix(x$par.cor[colnames(x$opt.adj) ,colnames(x$opt.adj) ])
+   	  rownames(x$opt.theta) <- colnames(x$opt.theta)
+  	  x$opt.theta <- Matrix(x$opt.theta [colnames(x$opt.adj) ,colnames(x$opt.adj)] )
+	  }else{
+	  cat(" isolated nodes are shown in the graph \n ")
+	}
+	
 	if(vis == "image.parcorMatrix") print(image(Matrix(x$par.cor), xlab=xlab, ylab=ylab, main= "partial correlation matrix", sub="") )
 	if(vis == "image.adj") print(image(Matrix(x$opt.adj), xlab=xlab, ylab=ylab, main= "adjacency matrix", sub=""))
 	if(vis == "image.precision") print(image(Matrix(x$opt.theta), xlab=xlab, ylab=ylab, main= "precision matrix", sub="")) 
